#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://glame.sourceforge.net/index.var
# source           : http://surfnet.dl.sourceforge.net/sourceforge/glame/glame-2.0.2-rc1.tar.gz

# Package name
NAME="glame"
# Source package version
VERSION="2.0.2-rc1"
# Zenwalk package version
ZENVERSION="2.0.2.rc1"
# Source code URL
SOURCE="http://surfnet.dl.sourceforge.net/sourceforge/glame/glame-$VERSION.tar.gz"
# ./configure options
CONFIGOPTIONS="--prefix=/usr --infodir=/usr/info"
# Files that should be placed in /usr/doc/package-version/
DOCS="ABOUT-NLS AUTHORS BUGS COPYING CREDITS ChangeLog INSTALL MAINTAINERS NEWS README TODO"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: GLAME -GNU/Linux Audio Mechanics
$NAME:
$NAME: GLAME is short for GNU/Linux Audio Mechanics! The project aims to
$NAME: present you with a powerful, fast, stable and easily extensible
$NAME: sound editor for Linux and compatible systems. And best of all,
$NAME: it's GPLed!
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Check to see if icons are present. If it's not, download it
if [ -f icons.tar.gz ]; then
	echo "Icon file already here, no need to download";
else
 	echo "Downloading icon file"
	wget -c http://users.zenwalk.org/user-accounts/gapan/$NAME/icons.tar.gz
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz
tar xvzf icons.tar.gz

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

# Configure and make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure $CONFIGOPTIONS
make $numjobs

# Install on temporary directory
make install DESTDIR=$PKG

# Fix the .desktop file
mkdir -p $PKG/usr/share/applications
grep -A 10 Desktop $PKG/usr/share/gnome/apps/Multimedia/glame.desktop > $PKG/usr/share/applications/glame.desktop 
rm -rf $PKG/usr/share/gnome
sed -i -e 's/.png//' $PKG/usr/share/applications/glame.desktop
echo "Categories=AudioVideo;Audio;" >> $PKG/usr/share/applications/glame.desktop

# Remove unwanted file
rm $PKG/usr/info/dir
rmdir $PKG/usr/include # this one's emtpy

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$ZENVERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$ZENVERSION

# Compress the info page(s)
find $PKG/usr/info -type f -exec gzip -9 {} \;

# Copy icons to the right place
ICONSIZES="48 32 24 16"
for i in $ICONSIZES; do
	mkdir -p $PKG/usr/share/icons/hicolor/$i\x$i/apps;
	mv $CWD/$NAME-$i.png $PKG/usr/share/icons/hicolor/$i\x$i/apps/$NAME.png;
done;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$ZENVERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$ZENVERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$ZENVERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$ZENVERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$ZENVERSION-$ARCH-$BUILD.tgz > $NAME-$ZENVERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
